@@ -1,7 +1,5 @@
 from feeluown.library import AbstractProvider
 from feeluown.library import (
-    ModelFlags,
-
     BaseModel,
     SongModel,
     ArtistModel,
@@ -14,16 +12,7 @@ from feeluown.library import (
     BriefPlaylistModel,
     BriefUserModel,
 )
-from feeluown.models import (
-    SongModel as SongModelV1,
-    ArtistModel as ArtistModelV1,
-    AlbumModel as AlbumModelV1,
-    PlaylistModel as PlaylistModelV1,
-    UserModel as UserModelV1,
-    SearchModel as SearchModelV1,
-
-    reverse,
-)
+from feeluown.library import reverse
 
 
 class ModelSerializerMixin:
@@ -32,19 +21,16 @@ class ModelSerializerMixin:
         # initialize fields that need to be serialized
         # if as_line option is set, we always use fields_display
         if self.opt_as_line or self.opt_brief:
-            if ModelFlags.v2 in model.meta.flags:
-                modelcls = type(model)
-                fields = [field for field in model.__fields__
-                          if field not in BaseModel.__fields__]
-                # Include properties.
-                pydantic_fields = ("__values__", "fields", "__fields_set__",
-                                   "model_computed_fields", "model_extra",
-                                   "model_fields_set")
-                fields += [prop for prop in dir(modelcls)
-                           if isinstance(getattr(modelcls, prop), property)
-                           and prop not in pydantic_fields]
-            else:
-                fields = model.meta.fields_display
+            modelcls = type(model)
+            fields = [field for field in model.__fields__
+                      if field not in BaseModel.__fields__]
+            # Include properties.
+            pydantic_fields = ("__values__", "fields", "__fields_set__",
+                               "model_computed_fields", "model_extra",
+                               "model_fields_set")
+            fields += [prop for prop in dir(modelcls)
+                       if isinstance(getattr(modelcls, prop), property)
+                       and prop not in pydantic_fields]
         else:
             fields = self._declared_fields
         items = [("provider", model.source),
@@ -61,7 +47,7 @@ class ModelSerializerMixin:
 
 class SongSerializerMixin:
     class Meta:
-        types = (SongModel, SongModelV1, BriefSongModel)
+        types = (SongModel, BriefSongModel)
         # since url can be too long, we put it at last
         fields = ('title', 'duration', 'album', 'artists')
         line_fmt = '{uri:{uri_length}}\t# {title:_18} - {artists_name:_20}'
@@ -69,28 +55,28 @@ class SongSerializerMixin:
 
 class ArtistSerializerMixin:
     class Meta:
-        types = (ArtistModel, ArtistModelV1, BriefArtistModel)
+        types = (ArtistModel, BriefArtistModel)
         fields = ('name', 'songs')
         line_fmt = '{uri:{uri_length}}\t# {name:_40}'
 
 
 class AlbumSerializerMixin:
     class Meta:
-        types = (AlbumModel, AlbumModelV1, BriefAlbumModel)
+        types = (AlbumModel, BriefAlbumModel)
         fields = ('name', 'artists', 'songs')
         line_fmt = '{uri:{uri_length}}\t# {name:_18} - {artists_name:_20}'
 
 
 class PlaylistSerializerMixin:
     class Meta:
-        types = (PlaylistModel, PlaylistModelV1, BriefPlaylistModel)
+        types = (PlaylistModel, BriefPlaylistModel)
         fields = ('name', )
         line_fmt = '{uri:{uri_length}}\t# {name:_40}'
 
 
 class UserSerializerMixin:
     class Meta:
-        types = (UserModel, UserModelV1, BriefUserModel)
+        types = (UserModel, BriefUserModel)
         fields = ('name', 'playlists')
         line_fmt = '{uri:{uri_length}}\t# {name:_40}'
 
@@ -106,7 +92,7 @@ class SearchSerializerMixin:
     """
 
     class Meta:
-        types = (SearchModelV1, )
+        types = ()
 
     def _get_items(self, result):
         fields = ('songs', 'albums', 'artists', 'playlists',)
